@@ -185,7 +185,7 @@ def cmd_2_image (app, plot):
         return out
     if "ditaa" in cmd:
         if plot_format in ["svg", "pdf"]:
-            cmd += " --svg" #ditaa support vector image by --svg parameter.
+            args.insert(1, "--svg") #ditaa support vector image by --svg parameter.
         args.extend([infname, outfname])
         # Ditaa must work on the target directory.
         os.chdir(path.join(app.builder.outdir, app.builder.imagedir))
